Mazovia encoding - Wikipedia

# Mazovia encoding

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

Mazovia encoding
Kermit | MAZOVIA
Alias(es) | cp667, cp790, cp991, MAZ
Language(s) | Polish
Classification | Extended ASCII, OEM code page
Based on | OEM-US
Other related encoding(s) | Fidonet Mazovia (MFD), Mazovia 157, FreeDOS-991

Mazovia encoding is used under DOS to represent Polish texts. Basically it is code page 437 with some positions filled with Polish letters. An important feature was that the block graphic characters of code page 437 remained unchanged. In contrast, IBM's later official Central European code page 852 did not preserve all block graphics, causing incorrect display in programs such as Norton Commander.

The Mazovia encoding was designed in 1984 by Jan Klimowicz of IMM [pl]. It was designed as part of a project to develop and produce a Polish IBM PC clone codenamed "Mazovia 1016 [pl]". The code page was therefore optimized for that computer's typical peripheral devices, a graphics card with dual switchable graphics, a keyboard using US English and Russian layouts and printers with Polish fonts. In 1986, the Polish National Bank (NBP) adopted the Mazovia encoding as a standard, thereby causing its widespread acceptance and distribution in Poland. They also were instrumental in Ipaco producing compatible computers with Taiwanese components under the direction of Zbigniew Jakubas [pl] and Krzysztof Sochacki.

Some ambiguity exists in the official code page assignment for the Mazovia encoding:

PTS-DOS and S/DOS support this encoding under code page 667 (CP667).[1] The same encoding was also called code page 991 (CP991) in some Polish software,[nb 1] however, the FreeDOS implementation of code page 991 seems not to be identical to this original encoding. The DOS code page switching file `NECPINW.CPI` for NEC Pinwriters supports the Mazovia encoding under both code pages 667 and 991.[1] FreeDOS has meanwhile introduced support for the original Mazovia encoding under code page 790 (CP790) as well. The Fujitsu DL6400 (Pro) / DL6600 (Pro) printers support the Mazovia encoding as well.[2] This encoding is known as code page 3843 in Star printers.

## Character set[edit]

Each character is shown with its equivalent Unicode code point.[3] Only the second half of the table (128–255) is shown, all of the first half (0–127) being the same as ASCII and code page 437.

Several variants of this encoding exists:

- Mazovia 157 (ś is at 9D instead of 9E)
- Fido Mazovia (ć is at 0x87 instead of 8D and Ć is at 0x80 instead of 0x95)
- FreeDOS Mazovia (złoty sign at 9B). FreeDOS supports this variant under code page 991, although the original definition of code page 991, which pre-dates FreeDOS, appears to have been identical to code page 667 / 790.

These variants are not fully compliant with the definition of code page 667 / 790 and should therefore not be associated with these numbers.

Code page 667 / 790
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
8_ 128 | Ç 00C7 | ü 00FC | é 00E9 | â 00E2 | ä 00E4 | à 00E0 | ą 0105 | ç 00E7 | ê 00EA | ë 00EB | è 00E8 | ï 00EF | î 00EE | ć 0107 | Ä 00C4 | Ą 0104
9_ 144 | Ę 0118 | ę 0119 | ł 0142 | ô 00F4 | ö 00F6 | Ć 0106 | û 00FB | ù 00F9 | Ś 015A | Ö 00D6 | Ü 00DC | ¢ 00A2 | Ł 0141 | ¥ 00A5 | ś 015B | ƒ 0192
A_ 160 | Ź 0179 | Ż 017B | ó 00F3 | Ó 00D3 | ń 0144 | Ń 0143 | ź 017A | ż 017C | ¿ 00BF | ⌐ 2310 | ¬ 00AC | ½ 00BD | ¼ 00BC | ¡ 00A1 | « 00AB | » 00BB
B_ 176 | ░ 2591 | ▒ 2592 | ▓ 2593 | │ 2502 | ┤ 2524 | ╡ 2561 | ╢ 2562 | ╖ 2556 | ╕ 2555 | ╣ 2563 | ║ 2551 | ╗ 2557 | ╝ 255D | ╜ 255C | ╛ 255B | ┐ 2510
C_ 192 | └ 2514 | ┴ 2534 | ┬ 252C | ├ 251C | ─ 2500 | ┼ 253C | ╞ 255E | ╟ 255F | ╚ 255A | ╔ 2554 | ╩ 2569 | ╦ 2566 | ╠ 2560 | ═ 2550 | ╬ 256C | ╧ 2567
D_ 208 | ╨ 2568 | ╤ 2564 | ╥ 2565 | ╙ 2559 | ╘ 2558 | ╒ 2552 | ╓ 2553 | ╫ 256B | ╪ 256A | ┘ 2518 | ┌ 250C | █ 2588 | ▄ 2584 | ▌ 258C | ▐ 2590 | ▀ 2580
E_ 224 | α 03B1 | ß 00DF | Γ 0393 | π 03C0 | Σ 03A3 | σ 03C3 | µ 00B5 | τ 03C4 | Φ 03A6 | Θ 0398 | Ω 03A9 | δ 03B4 | ∞ 221E | φ 03C6 | ε 03B5 | ∩ 2229
F_ 240 | ≡ 2261 | ± 00B1 | ≥ 2265 | ≤ 2264 | ⌠ 2320 | ⌡ 2321 | ÷ 00F7 | ≈ 2248 | ° 00B0 | ∙ 2219 | · 00B7 | √ 221A | ⁿ 207F | ² 00B2 | ■ 25A0 | NBSP 00A0

Letter Number Punctuation Symbol Other Undefined Differences from code page 437

## See also[edit]

- Kamenický encoding
- CWI-2 encoding
- Hardware code page

## Notes[edit]

1. ^ The Polish text converter PLC, developed by Marcin Gryszkalis between 1997-1999, supports the standard Mazovia encoding under code page 991 as well as under the symbolic handle MAZ. The Fidonet Mazovia encoding is supported under symbolic handle MFD instead.

## References[edit]

1. ^ a b
   Paul, Matthias R. (2001) [1996]. "Specification and reference documentation for NECPINW". NECPINW.CPI - DOS code page switching driver for NEC Pinwriters (2.08 ed.). FILESPEC.TXT from NECPI208.ZIP. Archived from the original on 2017-09-10. Retrieved 2013-04-22.
2. ^ Fujitsu DL6400/DL6600 Dot Matrix Printer User's Manual (PDF). Fujitsu Limited. April 1994. C147-E015-01EN. Archived (PDF) from the original on 2016-06-14. Retrieved 2016-06-14.
3. ^ Pinwriter Familie - Pinwriter - Epromsockel - Zusätzliche Zeichensätze / Schriftarten (Printed reference manual for optional font and codepage EPROMs for NEC Pinwriters, including custom variants) (in German) (00 3/93 ed.). NEC Deutschland GmbH. 1993. (NB. Some dot matrix printers of the NEC Pinwriter series, namely the P3200/P3300 (P20/P30), P6200/P6300 (P60/P70), P9300 (P90), P7200/P7300 (P62/P72), P22Q/P32Q, P3800/P3900 (P42Q/P52Q), P1200/P1300 (P2Q/P3Q), P2000 (P2X) and P8000 (P72X), supported the installation of optional font EPROMs, where this encoding was included in ROM #8 "Polish". It could be invoked via escape sequence `ESC R (n)` with (n) = 21.)

Retrieved from "https://en.wikipedia.org/w/index.php?title=Mazovia_encoding&oldid=973387879"
Categories:

- DOS code pages

Hidden categories:

- CS1 German-language sources (de)
- Use dmy dates from December 2019